==> SMILA-1.1-core-source.zip: org.eclipse.smila.importing.crawler.web.test/code/src/org/eclipse/smila/importing/crawler/web/test/AllTests.java <==
/*******************************************************************************
 * Copyright (c) 2008, 2011 Attensity Europe GmbH and brox IT Solutions GmbH. All rights reserved. This program and the
 * accompanying materials are made available under the terms of the Eclipse Public License v1.0 which accompanies this
 * distribution, and is available at http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: Juergen Schumacher (Attensity Europe GmbH) - initial API and implementation
 *******************************************************************************/
package org.eclipse.smila.importing.crawler.web.test;

import junit.framework.Test;
import junit.framework.TestSuite;

/**
 * Test suite for org.eclipse.smila.importing.crawler.web bundle.
 */
public final class AllTests {

  /** name of test bundle. */
  public static final String BUNDLE_ID = "org.eclipse.smila.importing.crawler.web.test";

  /** Private default Constructor to avoid instance creation. */
  private AllTests() {
  }

  /**
   * Creates test suite.
   */
  public static Test suite() {
    final TestSuite suite = new TestSuite("Tests for org.eclipse.smila.importing.crawler.web.test bundle");
    suite.addTestSuite(TestDefaultFetcher.class);
    suite.addTestSuite(TestDefaultLinkExtractor.class);
    suite.addTestSuite(TestDefaultLinkFilter.class);
    suite.addTestSuite(TestDefaultRecordProducer.class);
    suite.addTestSuite(TestWebCrawlerWorker.class);
    suite.addTestSuite(TestWebExtractorWorker.class);
    return suite;
  }

}

==> SMILA-1.3-core-source.zip: org.eclipse.smila.importing.crawler.web.test/code/src/org/eclipse/smila/importing/crawler/web/test/AllTests.java <==
/*******************************************************************************
 * Copyright (c) 2008, 2011 Attensity Europe GmbH and brox IT Solutions GmbH. All rights reserved. This program and the
 * accompanying materials are made available under the terms of the Eclipse Public License v1.0 which accompanies this
 * distribution, and is available at http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: Juergen Schumacher (Attensity Europe GmbH) - initial API and implementation
 *******************************************************************************/
package org.eclipse.smila.importing.crawler.web.test;

import junit.framework.Test;
import junit.framework.TestSuite;

/**
 * Test suite for org.eclipse.smila.importing.crawler.web bundle.
 */
public final class AllTests {

  /** name of test bundle. */
  public static final String BUNDLE_ID = "org.eclipse.smila.importing.crawler.web.test";

  /** Private default Constructor to avoid instance creation. */
  private AllTests() {
  }

  /**
   * Creates test suite.
   */
  public static Test suite() {
    final TestSuite suite = new TestSuite("Tests for org.eclipse.smila.importing.crawler.web.test bundle");
    suite.addTestSuite(TestDefaultFetcher.class);
    suite.addTestSuite(TestDefaultLinkExtractor.class);
    suite.addTestSuite(TestDefaultLinkFilter.class);
    suite.addTestSuite(TestDefaultRecordProducer.class);
    suite.addTestSuite(TestRobotsTxt.class);
    suite.addTestSuite(TestUriHelper.class);
    suite.addTestSuite(TestWebCrawlerWorker.class);
    suite.addTestSuite(TestWebFetcherWorker.class);
    suite.addTestSuite(TestWebExtractorWorker.class);
    return suite;
  }

}
